# RHEL-6 specific changes to spec file vs upstream
#
# drop Requires: fsck.xfs (another rhn channel, not available with HA)
# ExclusiveArch: i686 x86_64
# don't build ldirectord
# drop drbd, smb and tomcat5 in install section
# Conflicts with old rgmanager

#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#






# 
# Since this spec file supports multiple distributions, ensure we
# use the correct group for each.
#

# SSLeay (required by ldirectord)
%if 0%{?suse_version}
%global SSLeay perl-Net_SSLeay
%else
%global SSLeay perl-Net-SSLeay
%endif

# determine the ras-set to process based on configure invokation
%bcond_without rgmanager
%bcond_without linuxha

Name:		resource-agents
Summary:	Open Source HA Reusable Cluster Resource Scripts
Version:	3.9.2
Release:	7%{?rcver:%{rcver}}%{?numcomm:.%{numcomm}}%{?alphatag:.%{alphatag}}%{?dirty:.%{dirty}}%{?dist}
License:	GPLv2+ and LGPLv2+
URL:		http://to.be.defined.com/
%if 0%{?fedora} || 0%{?centos_version} || 0%{?rhel}
Group:		System Environment/Base
%else
Group:		Productivity/Clustering/HA
%endif
Epoch:		2
Source0:	%{name}-%{version}%{?rcver:%{rcver}}%{?numcomm:.%{numcomm}}%{?alphatag:-%{alphatag}}%{?dirty:-%{dirty}}.tar.bz2
Patch0:		bz694816-rgmanager-postgresql-script-now-properly-recognizes.patch
Patch1:		bz709400-rgmanager-Return-error-proper-error-code-for-oc.patch
Patch2:		bz678497-Low-Improve-netfs-unmount-when-server-is-unavailable.patch
Patch3:		bz727643-Fixed-scripts-for-use-with-rgmanager.patch
Patch4:		bz727643-rgmanager-Fixed-minor-typos-in-rgmanager-resource-ag.patch
Patch5:		bz727643-Fix-ocf-tester-to-use-bash-when-testing-agents.patch
Patch6:		bz711852-rgmanager-Fix-ASEHAagent-to-make-server_name-unique.patch
Obsoletes:	heartbeat-resources <= %{version}
Provides:	heartbeat-resources = %{version}
Conflicts:	rgmanager < 3.0.12.1

ExclusiveArch: i686 x86_64

## Setup/build bits
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

# Build dependencies
BuildRequires: automake autoconf pkgconfig
BuildRequires: perl python-devel
BuildRequires: libxslt glib2-devel
BuildRequires: which

%if 0%{?fedora} || 0%{?centos_version} || 0%{?rhel}
BuildRequires: cluster-glue-libs-devel
BuildRequires: docbook-style-xsl docbook-dtds
%if 0%{?rhel} == 0
BuildRequires: libnet-devel
%endif
%endif

%if 0%{?suse_version}  
%if 0%{?suse_version} >= 1140
BuildRequires:  libnet1
%else
BuildRequires:  libnet
%endif
BuildRequires:  libglue-devel
BuildRequires:  libxslt docbook_4 docbook-xsl-stylesheets
%endif

## Runtime deps
## These apply to rgmanager agents only to guarantee agents
## are functional
%if %{with rgmanager}
# system tools shared by several agents
Requires: /bin/bash /bin/grep /bin/sed /bin/gawk
Requires: /bin/ps /usr/bin/pkill /bin/hostname
Requires: /sbin/fuser
Requires: /sbin/findfs /bin/mount

# fs.sh
Requires: /sbin/quotaon /sbin/quotacheck
Requires: /sbin/fsck
Requires: /sbin/fsck.ext2 /sbin/fsck.ext3 /sbin/fsck.ext4

# ip.sh
Requires: /sbin/ip /usr/sbin/ethtool
Requires: /sbin/rdisc /usr/sbin/arping /bin/ping /bin/ping6

# lvm.sh
Requires: /sbin/lvm

# netfs.sh
Requires: /sbin/mount.nfs /sbin/mount.nfs4 /sbin/mount.cifs
Requires: /usr/sbin/rpc.nfsd /sbin/rpc.statd /usr/sbin/rpc.mountd
%endif

%description
A set of scripts to interface with several services to operate in a
High Availability environment for both Pacemaker and rgmanager
service managers.

###%if %{?rhel} == 0
%if %{with linuxha}
%package -n ldirectord
License:	GPLv2+
Summary:	A Monitoring Daemon for Maintaining High Availability Resources
%if 0%{?fedora} || 0%{?centos_version} || 0%{?rhel}
Group:		System Environment/Daemons
%else
Group:		Productivity/Clustering/HA
%endif
Obsoletes:	heartbeat-ldirectord <= %{version}
Provides:	heartbeat-ldirectord = %{version}
Requires:       %{SSLeay} perl-libwww-perl perl-MailTools
Requires:       ipvsadm logrotate
%if 0%{?fedora_version}
Requires:	perl-Net-IMAP-Simple-SSL
Requires(post):	/sbin/chkconfig
Requires(preun):/sbin/chkconfig
%endif

%description -n ldirectord
The Linux Director Daemon (ldirectord) was written by Jacob Rief.
<jacob.rief@tiscover.com>

ldirectord is a stand alone daemon for monitoring the services on real
servers. Currently, HTTP, HTTPS, and FTP services are supported.
lditrecord is simple to install and works with the heartbeat code
(http://www.linux-ha.org/).

See 'ldirectord -h' and linux-ha/doc/ldirectord for more information.
%endif
###%endif

%prep
%if 0%{?suse_version} == 0 && 0%{?fedora} == 0 && 0%{?centos_version} == 0 && 0%{?rhel} == 0
%{error:Unable to determine the distribution/version. This is generally caused by missing /etc/rpm/macros.dist. Please install the correct build packages or define the required macros manually.}
exit 1
%endif
%setup -q -n %{name}-%{version}%{?rcver:%{rcver}}%{?numcomm:.%{numcomm}}%{?alphatag:-%{alphatag}}%{?dirty:-%{dirty}}
%patch0 -p1 -b .bz694816
%patch1 -p1 -b .bz709400
%patch2 -p1 -b .bz678497
%patch3 -p1 -b .bz727643
%patch4 -p1 -b .bz727643-2
%patch5 -p1 -b .bz727643-3
%patch6 -p1 -b .bz711852

%build
if [ ! -f configure ]; then
	./autogen.sh
fi

%if 0%{?fedora} >= 11 || 0%{?centos_version} > 5 || 0%{?rhel} > 5
CFLAGS="$(echo '%{optflags}')"
%global conf_opt_rsctmpdir "--with-rsctmpdir=%{_var}/run/heartbeat/rsctmp"
%global conf_opt_fatal "--enable-fatal-warnings=no"
%else
CFLAGS="${CFLAGS} ${RPM_OPT_FLAGS}"
%global conf_opt_fatal "--enable-fatal-warnings=yes"
%endif

%if %{with rgmanager}
%global rasset rgmanager
%endif
%if %{with linuxha}
%global rasset linux-ha
%endif
%if %{with rgmanager} && %{with linuxha}
%global rasset all
%endif

export CFLAGS

%configure \
	%{?conf_opt_rsctmpdir:%conf_opt_rsctmpdir} \
	%{conf_opt_fatal} \
	--with-pkg-name=%{name} \
	--with-ras-set=%{rasset}

%if %{defined jobs}
JFLAGS="$(echo '-j%{jobs}')"
%else
JFLAGS="$(echo '%{_smp_mflags}')"
%endif

make $JFLAGS

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
## tree fixup
# remove docs (there is only one and they should come from doc sections in files)
rm -rf %{buildroot}/usr/share/doc/resource-agents

%if %{with linuxha}
%if 0%{?suse_version}
test -d %{buildroot}/sbin || mkdir %{buildroot}/sbin
(
  cd %{buildroot}/sbin
  ln -sf /%{_sysconfdir}/init.d/ldirectord rcldirectord 
) || true
%endif
%endif

# rhel specific bits:
# ldirectord isn't included on RHEL
#find %{buildroot} -name 'ldirectord.*' -exec rm -f {} \;
#find %{buildroot} -name 'ldirectord' -exec rm -f {} \;

# drop drbd, smb and tomcat5
(
  cd %{buildroot}/%{_datadir}/cluster
  rm -f drbd.* smb.sh tomcat-5.*
)
ln -s /usr/share/cluster/relaxng/ra-api-1-modified.dtd %{buildroot}/usr/share/resource-agents/

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.GPLv3 ChangeLog
%if %{with linuxha}
%doc doc/README.webapps
%doc %{_datadir}/%{name}/ra-api-1.dtd
%doc %{_datadir}/%{name}/ra-api-1-modified.dtd
%endif

%if %{with rgmanager}
%{_datadir}/cluster
%{_sbindir}/rhev-check.sh
%endif

%if %{with linuxha}
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/lib

/usr/lib/ocf/lib/heartbeat

/usr/lib/ocf/resource.d/heartbeat
%if %{with rgmanager}
/usr/lib/ocf/resource.d/redhat
%endif

%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/ocft
%{_datadir}/%{name}/ocft/configs
%{_datadir}/%{name}/ocft/caselib
%{_datadir}/%{name}/ocft/README
%{_datadir}/%{name}/ocft/README.zh_CN

%{_sbindir}/ocf-tester
%{_sbindir}/ocft
%{_sbindir}/sfex_init
%{_sbindir}/sfex_stat

%{_includedir}/heartbeat

%if 0%{?fedora} >= 11 || 0%{?centos_version} > 5 || 0%{?rhel} > 5
%dir %{_var}/run/heartbeat/rsctmp
%else
%dir %attr (1755, root, root)	%{_var}/run/resource-agents
%endif

%{_mandir}/man7/*.7*
%{_mandir}/man8/ocf-tester.8*
%{_mandir}/man8/sfex_init.8*

# For compatability with pre-existing agents
%dir %{_sysconfdir}/ha.d
%{_sysconfdir}/ha.d/shellfuncs

%{_libdir}/heartbeat

%if %{with rgmanager}
%post -n resource-agents
ccs_update_schema > /dev/null 2>&1 ||:
%endif

###%if %{?rhel} == 0
%if 0%{?suse_version}
%preun -n ldirectord
%stop_on_removal ldirectord
%postun -n ldirectord
%insserv_cleanup
%endif

%if 0%{?fedora}
%preun -n ldirectord
/sbin/chkconfig --del ldirectord
%postun -n ldirectord -p /sbin/ldconfig
%post -n ldirectord
/sbin/chkconfig --add ldirectord
%endif

%files -n ldirectord
%defattr(-,root,root)
%{_sbindir}/ldirectord
%doc ldirectord/ldirectord.cf COPYING
%{_mandir}/man8/ldirectord.8*
%config(noreplace) %{_sysconfdir}/logrotate.d/ldirectord
%dir %{_sysconfdir}/ha.d
%dir %{_sysconfdir}/ha.d/resource.d
%{_sysconfdir}/ha.d/resource.d/ldirectord
%{_sysconfdir}/init.d/ldirectord
%if 0%{?suse_version}
/sbin/rcldirectord
%endif
%if 0%{?fedora}
/usr/lib/ocf/resource.d/heartbeat/ldirectord
%endif
%endif
###%endif

%changelog
* Tue Oct 18 2011 Chris Feist <cfeist@redhat.com> - 3.9.2-7
- Require server_name in ASEHAagent to be unique
- Resolves: rhbz#711852

* Fri Aug 12 2011 Chris Feist <cfeist@redhat.com> - 3.9.2-4
- Create a link for the modified dtd for rgmanager
- Fix ocf-tester so rgmanager agents requiring bash don't cause syntax errors
- Resolves: rhbz#727643

* Thu Aug 11 2011 Chris Feist <cfeist@redhat.com> - 3.9.2-3
- Main rgmanager resource agents now use proper return codes for use with
  pacemaker.
- NFS mounts now unmount faster when the network is lost.
- Resolves: rhbz#678497 rhbz#727643

* Fri Jul 22 2011 Chris Feist <cfeist@redhat.com> - 3.9.2-2
- Postgres-8 resource agent now properly detects if postgresql was started
- fs.sh resource agent now returns the proper response code when a device
  does not yet exist.
- Resolves: rhbz#709400 rhbz#694816

* Mon Jul 11 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.9.2-1
- Rebase package on top of new upstream
  * ship xsl and rng files required to build relaxng schema
  * drop local copy of sfex_init.8
  * drop bz711852-Fix-ASEHAagent-to-allow-for-multiple-ASEHA-agents-on.patch
    included upstream
- spec file update:
  add %post to generate new relaxng schema
  Resolves: rhbz#707127

* Fri Jun 24 2011 Chris Feist <cfeist@redhat.com> - 3.9.1-2
- Fix ASEHAagent to allow for multiple ASEHA agents
- Resolves: rhbz#711852

* Tue Jun 21 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.12.1-1
- Rebase package on top of new upstream:
  resource-agents: Improve LD_LIBRARY_PATH handling by SAP*
  resource-agents: Add resource type to logging
  oracledb.sh resource script should attempt a clean shutdown first
  resource-agent does not remove nfs service temp dirs when using nfslock=1
  Listen line in generated httpd.conf incorrect
  Include rhev-check upstream
- spec file update:
  * drop all patches
  * resync with upstream spec file. See top section for local deltas
  Resolves: rhbz#707127, rhbz#705763, rhbz#667217
- Move rgmanager S/Lang from resource-agents to rgmanager:
  * Add versioned Conflicts on rgmanager to avoid file conflicts
  Resolves: rhbz#693518

* Fri Apr 15 2011 Lon Hohberger <lhh@redhat.com> - Version: 3.0.12-22
- resource-agents: Fix nfs mount contexts
  (fix_nfs_mount_contexts.patch)
  Resolves: rhbz#635828

* Wed Apr 06 2011 Lon Hohberger <lhh@redhat.com> - Version: 3.0.12-21
- Mirror dev failure in HA LVM can cause service failur
  (fix_bug_683213_mirror_dev_failure_in_ha_lvm_can_cause_service_failure.patch)
  Resolves: rhbz#683213

* Tue Mar 15 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.12-20
- resource-agents: fs-lib: fix do_monitor device mapping
  (fs_lib_fix_do_monitor_device_mapping.patch)
  Resolves: rhbz#669832

* Thu Feb 03 2011 Lon Hohberger <lhh@redhat.com> - 3.0.12-19
- resource-agents: Add multi-instance Oracle database agents
  (add_multi_instance_oracle_database_agents.patch)
  Resolves: rhbz#629275
- resource-agents: Stop using '-' as 1st char of log messages
  (stop_using_as_1st_char_of_log_messages.patch)
  Resolves: rhbz#633856
- resource-agents: Use literal quotes for tr calls
  (use_literal_quotes_for_tr_calls.patch)
  Resolves: rhbz#639252
- resource-agents: Fix migrateuriopt setting
  (fix_migrateuriopt_setting.patch)
  Resolves: rhbz#660337
- resource-agents: Support convalesce w/ central_processing
  (support_convalesce_w_central_processing.patch)
  rgmanager: Add failure tolerances to resources.rng
  (add_failure_tolerances_to_resources_rng.patch)
  Resolves: rhbz#674710

* Fri Jan 28 2011 Marek Grac <mgrac@redhat.com> - 3.0.12-18
- Disable updates to static routes by RHCS IP tooling
  (resource-agents-Add-option-disable_rdisc-to-ip.sh.patch)
  Resolves: rhbz#621538

* Tue Nov 02 2010 Marek Grac <mgrac@redhat.com> - 3.0.12-17
- fix resource agent for named
  (resource-agents-fix-resource-agent-for-named.patch)
  Resolves: rhbz#648897

* Tue Oct 05 2010 Lon Hohberger <lhh@redhat.com> - Version: 3.0.12-16
- resource-agents: fix utility to obtain data from ccs_tool
  (fix_utility_to_obtain_data_from_ccs_tool.patch)
  Resolves: rhbz#631943

* Wed Jul 21 2010 Marek Grac <mgrac@redhat.com> - 3.0.12-15
- postgresql RA does not work correctly with netmask
  (psql_does_not_work_correctly_with_netmask.patch)
  Resolves: rhbz#614457

* Tue Jul 20 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-14
- resource-agents: Drop tomcat-5 from build
  (drop_tomcat_5_from_build.patch)
  Resolves: rhbz#593721

* Wed Jul 14 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-13
- Allow other values for "yes" in fs-lib when unmounting
  file systems
  (fs-lib_allow_other_values_for_yes.patch)
  Resolves: rhbz#614421

* Wed Jul 14 2010 Marek Grac <mgrac@redhat.com> - 3.0.12-12
- postgres RA will fail to stop gracefully if there 
  is active client connected
  (sigquit_if_sigterm_was_not_fast_enough.patch)
  Resolves: rhbz#612165
- new RA for tomcat6
  (resource_agent_tomcat-6.patch)
  (tomcat-6_change_build_system.patch)
  Resolves: rhbz#593721

* Mon Jul 12 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-10
- Fix changelog for 3.0.12-9 date
- Add RHEVM status program
  (add_rhevm_status_program.patch)
  Resolves: rhbz#609497

* Fri Jul 09 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-9
- Add NFSv4 server support
  (add_nfsv4_support.patch)
  (install_nfsv4_agent.patch)
  Resolves: rhbz#595547
- Fix migration mapping behavior
  (fix_migration_mapping_behavior.patch)
  Resolves: rhbz#596918

* Wed Jun 30 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-8
- Make fs-lib resolve links before checking for block devices
  (fix_incorrect_link_resolution_in_fs_lib.patch)
  Resolves: rhbz#609579

* Wed Jun 30 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-7
- Make vm.sh honor start and stop timeouts
  (Make_vm.sh_use_stop_start_timeouts.patch)
  Resolves: rhbz#606754

* Fri Jun 25 2010 Lon Hohberger <lhh@redhat.com> - 3.0.12-6
- Add missing documentation for resource agents
  (add_missing_resource_docs.patch)
- Clean up recursion in scheman output and documentation
  (clean_up_recursion_and_documentation.patch)
  Resolves: rhbz#606470

* Thu Jun  3 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.12-5
- Fix incorrect default for VM.sh agent
  (resolve_incorrect_default_for_vm_agent.patch)
  Resolves: rhbz#599643

* Fri May 28 2010 Andrew Beekhof <andrew@beekhof.net> - 3.0.12-4
- Add missing man pages
  (Add Source2: ocf-tester.8 and Source3: sfex_init.8)
  Resolves: rhbz#594332

* Wed May 19 2010 Andrew Beekhof <andrew@beekhof.net> - 3.0.12-3
- Do not package ldirectord on RHEL
  Resolves: rhbz#577264

* Wed May 19 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.12-2
- Drop Requires on xfsprogs since package moved to another channel
  Resolves: rhbz#593433
- Fix HALVM: lvm agent incorrectly reports vg is in volume_list
  (halvm_lvm_agent_incorrectly_reports_vg_in_volume_list.patch)
  Resolves: rhvz#593108

* Wed May 12 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.12-1
- Rebase on top of new upstream bug fix only release:
  * drop all bug fix patches.
  * refresh patches with official SHA1 git commits from RHEL6
    upstream branch:
    - drop_support_for_drbd_and_smb.patch
  * Addresses the follwing issues:
    from 3.0.12 release:
  Resolves: rhbz#582754, rhbz#582753, rhbz#585217, rhbz#583789
  * Rebase:
  Resolves: rhbz#582353
- Stop build on ppc and ppc64.
  Resolves: rhbz#590997
- Switch to file based Requires.
  Also address several other problems related to missing runtime
  components in different agents.
  With the current Requires: set, we guarantee all basic functionalities
  out of the box for lvm/fs/clusterfs/netfs/networking.
  Resolves: rhbz#584800
- New pacemaker agents upstream release
  * Patched build process to correctly generate ldirectord man page
  + High: pgsql: properly implement pghost parameter
  + High: RA: mysql: fix syntax error
  + High: SAPInstance RA: do not rely on op target rc when monitoring clones (lf#2371)
  + High: set the HA_RSCTMP directory to /var/run/resource-agents (lf#2378)
  + High: RA: vmware: fix set_environment() invocation (LF 2342)
  + High: RA: vmware: update to version 0.2
  + Medium: IPaddr/IPaddr2: add a description of the assumption in meta-data
  + Medium: IPaddr: return the correct code if interface delete failed
  + Medium: nfsserver: rpc.statd as the notify cmd does not work with -v (thanks to Carl Lewis)
  + Medium: oracle: reduce output from sqlplus to the last line for queries (bnc#567815)
  + Medium: pgsql: implement "config" parameter
  + Medium: RA: iSCSITarget: follow changed IET access policy
  + Medium: Filesystem: prefer /proc/mounts to /etc/mtab for non-bind mounts (lf#2388)
  + Medium: IPaddr2: don't bring the interface down on stop (thanks to Lars Ellenberg)
  + Medium: IPsrcaddr: modify the interface route (lf#2367)
  + Medium: ldirectord: Allow multiple email addresses (LF 2168)
  + Medium: ldirectord: fix setting defaults for configfile and ldirectord (lf#2328)
  + Medium: meta-data: improve timeouts in most resource agents
  + Medium: nfsserver: use default values (lf#2321)
  + Medium: ocf-shellfuncs: don't log but print to stderr if connected to a terminal
  + Medium: ocf-shellfuncs: don't output to stderr if using syslog
  + Medium: oracle/oralsnr: improve exit codes if the environment isn't valid
  + Medium: RA: iSCSILogicalUnit: fix monitor for STGT
  + Medium: RA: make sure that OCF_RESKEY_CRM_meta_interval is always defined (LF 2284)
  + Medium: RA: ManageRAID: require bash
  + Medium: RA: ManageRAID: require bash
  + Medium: RA: VirtualDomain: bail out early if config file can't be read during probe (Novell 593988)
  + Medium: RA: VirtualDomain: fix incorrect use of __OCF_ACTION
  + Medium: RA: VirtualDomain: improve error messages
  + Medium: RA: VirtualDomain: spin on define until we definitely have a domain name
  + Medium: Route: add route table parameter (lf#2335)
  + Medium: sfex: don't use pid file (lf#2363,bnc#585416)
  + Medium: sfex: exit with success on stop if sfex has never been started (bnc#585416)

* Tue Mar  2 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.9-1
- new upstream release
  Resolves: rhbz#569959
- spec file update:
  * update spec file copyright date
  * use bz2 tarball

* Thu Feb 25 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.7-5
- Resolves: rhbz#568010
- Do not build resource-agents on s390 and s390x.

* Mon Feb 22 2010 Marek Grac <mgrac@redhat.com> - 3.0.7-4
- Checksum error occurs on HA-LVM
- status on clusterfs "gfs" returned 1 (generic error)
- Resolves rhbz#563555 rhbz#558664

* Fri Feb 19 2010 Marek Grac <mgrac@redhat.com> - 3.0.7-3
- resource-agents can't be used by Pacemaker
- Resolves: rhbz#566176

* Wed Jan 13 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.7-2
- Drop support for drbd and smb (PM-drop-support-for-drbd-and-smb-resource-agents.patch)
- Explicitly list python as BuildRequires

* Mon Jan 11 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.7-1
- New rgmanager resource agents upstream release

* Mon Jan 11 2010 Andrew Beekhof <andrew@beekhof.net> - 3.0.6-2
- Update Pacameker agents to upstream version: c76b4a6eb576
  + High: RA: VirtualDomain: fix forceful stop (LF 2283)
  + High: apache: monitor operation of depth 10 for web applications (LF 2234)
  + Medium: IPaddr2: CLUSTERIP/iptables rule not always inserted on failed monitor (LF 2281)
  + Medium: RA: Route: improve validate (LF 2232)
  + Medium: mark obsolete RAs as deprecated (LF 2244)
  + Medium: mysql: escalate stop to KILL if regular shutdown doesn't work

* Mon Dec 7 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.6-1
- New rgmanager resource agents upstream release
- spec file update:
  * use global instead of define
  * use new Source0 url
  * use %name macro more aggressively

* Mon Dec 7 2009 Andrew Beekhof <andrew@beekhof.net> - 3.0.5-2
- Update Pacameker agents to upstream version: bc00c0b065d9
  + High: RA: introduce OCF_FUNCTIONS_DIR, allow it to be overridden (LF2239)
  + High: doc: add man pages for all RAs (LF2237)
  + High: syslog-ng: new RA
  + High: vmware: make meta-data work and several cleanups (LF 2212)
  + Medium: .ocf-shellfuncs: add ocf_is_probe function
  + Medium: Dev: make RAs executable (LF2239)
  + Medium: IPv6addr: ifdef out the ip offset hack for libnet v1.1.4 (LF 2034)
  + Medium: add mercurial repository version information to .ocf-shellfuncs
  + Medium: build: add perl-MailTools runtime dependency to ldirectord package (LF 1469)
  + Medium: iSCSITarget, iSCSILogicalUnit: support LIO
  + Medium: nfsserver: use check_binary properly in validate (LF 2211)
  + Medium: nfsserver: validate should not check if nfs_shared_infodir exists (thanks to eelco@procolix.com) (LF 2219)
  + Medium: oracle/oralsnr: export variables properly
  + Medium: pgsql: remove the previous backup_label if it exists
  + Medium: postfix: fix double stop (thanks to Dinh N. Quoc)
  + RA: LVM: Make monitor operation quiet in logs (bnc#546353)
  + RA: Xen: Remove instance_attribute "allow_migrate" (bnc#539968)
  + ldirectord: OCF agent: overhaul

* Fri Nov 20 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.5-1
- New rgmanager resource agents upstream release

* Wed Oct 28 2009 Andrew Beekhof <andrew@beekhof.net> - 3.0.4-2
- Update Pacameker agents to upstream version: e2338892f59f
  + High: send_arp - turn on unsolicited mode for compatibilty with the libnet version's exit codes
  + High: Trap sigterm for compatibility with the libnet version of send_arp
  + Medium: Bug - lf#2147: IPaddr2: behave if the interface is down
  + Medium: IPv6addr: recognize network masks properly
  + Medium: RA: VirtualDomain: avoid needlessly invoking "virsh define"

* Wed Oct 21 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.4-1
- New rgmanager resource agents upstream release

* Mon Oct 12 2009 Andrew Beekhof <andrew@beekhof.net> - 3.0.3-3
- Update Pacameker agents to upstream version: 099c0e5d80db
  + Add the ha_parameter function back into .ocf-shellfuncs.
  + Bug bnc#534803 - Provide a default for MAILCMD
  + Fix use of undefined macro @HA_NOARCHDATAHBDIR@
  + High (LF 2138): IPsrcaddr: replace 0/0 with proper ip prefix (thanks to Michael Ricordeau and Michael Schwartzkopff)
  + Import shellfuncs from heartbeat as badly written RAs use it
  + Medium (LF 2173): nfsserver: exit properly in nfsserver_validate
  + Medium: RA: Filesystem: implement monitor operation
  + Medium: RA: VirtualDomain: loop on status if libvirtd is unreachable
  + Medium: RA: VirtualDomain: loop on status if libvirtd is unreachable (addendum)
  + Medium: RA: iSCSILogicalUnit: use a 16-byte default SCSI ID
  + Medium: RA: iSCSITarget: be more persistent deleting targets on stop
  + Medium: RA: portblock: add per-IP filtering capability
  + Medium: mysql-proxy: log_level and keepalive parameters
  + Medium: oracle: drop spurious output from sqlplus
  + RA: Filesystem: allow configuring smbfs mounts as clones

* Wed Sep 23 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.3-1
- New rgmanager resource agents upstream release

* Thu Aug 20 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.1-1
- New rgmanager resource agents upstream release

* Tue Aug 18 2009 Andrew Beekhof <andrew@beekhof.net> - 3.0.0-16
- Create an ldirectord package
- Update Pacameker agents to upstream version: 2198dc90bec4
  + Build: Import ldirectord.
  + Ensure HA_VARRUNDIR has a value to substitute
  + High: Add findif tool (mandatory for IPaddr/IPaddr2)
  + High: IPv6addr: new nic and cidr_netmask parameters
  + High: postfix: new resource agent
  + Include license information
  + Low (LF 2159): Squid: make the regexp match more precisely output of netstat
  + Low: configure: Fix package name.
  + Low: ldirectord: add dependency on $remote_fs.
  + Low: ldirectord: add mandatory required header to init script.
  + Medium (LF 2165): IPaddr2: remove all colons from the mac address before passing it to send_arp
  + Medium: VirtualDomain: destroy domain shortly before timeout expiry
  + Medium: shellfuncs: Make the mktemp wrappers work.
  + Remove references to Echo function
  + Remove references to heartbeat shellfuncs.
  + Remove useless path lookups
  + findif: actually include the right header. Simplify configure.
  + ldirectord: Remove superfluous configure artifact.
  + ocf-tester: Fix package reference and path to DTD.

* Tue Aug 11 2009 Ville Skyttä <ville.skytta@iki.fi> - 3.0.0-15
- Use bzipped upstream hg tarball.

* Wed Jul 29 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-14
- Merge Pacemaker cluster resource agents:
  * Add Source1.
  * Drop noarch. We have real binaries now.
  * Update BuildRequires.
  * Update all relevant prep/build/install/files/description sections.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul  8 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-12
- spec file updates:
  * Update copyright header
  * final release.. undefine alphatag

* Thu Jul  2 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-11.rc4
- New upstream release.

* Sat Jun 20 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-10.rc3
- New upstream release.

* Wed Jun 10 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-9.rc2
- New upstream release + git94df30ca63e49afb1e8aeede65df8a3e5bcd0970

* Tue Mar 24 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-8.rc1
- New upstream release.
- Update BuildRoot usage to preferred versions/names

* Mon Mar  9 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-7.beta1
- New upstream release.

* Fri Mar  6 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-6.alpha7
- New upstream release.

* Tue Mar  3 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-5.alpha6
- New upstream release.

* Tue Feb 24 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-4.alpha5
- Drop Conflicts with rgmanager.

* Mon Feb 23 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-3.alpha5
- New upstream release.

* Thu Feb 19 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-2.alpha4
- Add comments on how to build this package.

* Thu Feb  5 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-1.alpha4
- New upstream release.
- Fix datadir/cluster directory ownership.

* Tue Jan 27 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.0.0-1.alpha3
  - Initial packaging
